# Python Rainwave Client

This is a Python client library for [Rainwave][a]. Documentation is available at
[https://python-rainwave-client.subtlecoolness.com/][b].

[a]: https://rainwave.cc/api4/
[b]: https://python-rainwave-client.subtlecoolness.com/

## Requirements

This library requires no dependencies outside the Python standard library.

## Installation

Install with `pip`:

    pip install python-rainwave-client
